@@ -97,18 +97,6 @@ local external_map_schema = ts.shape {
 local rspamd_http = require "rspamd_http"
 local ucl = require "ucl"
 
-local function url_encode_string(str)
-  str = string.gsub(str, "([^%w _%%%-%.~])",
-      function(c)
-        return string.format("%%%02X", string.byte(c))
-      end)
-  str = string.gsub(str, " ", "+")
-  return str
-end
-
-assert(url_encode_string('上海+中國') == '%E4%B8%8A%E6%B5%B7%2B%E4%B8%AD%E5%9C%8B')
-assert(url_encode_string('? and the Mysterians') == '%3F+and+the+Mysterians')
-
 local function query_external_map(map_config, upstreams, key, callback, task)
   local http_method = (map_config.method == 'body' or map_config.method == 'form') and 'POST' or 'GET'
   local upstream = upstreams:get_upstream_round_robin()
@@ -127,7 +115,7 @@ local function query_external_map(map_config, upstreams, key, callback, task)
         key = key
       }
     elseif map_config.method == 'query' then
-      url = string.format('%s?key=%s', url, url_encode_string(tostring(key)))
+      url = string.format('%s?key=%s', url, lua_util.url_encode_string(tostring(key)))
     end
   elseif type(key) == 'table' then
     if map_config.method == 'body' then
@@ -150,7 +138,7 @@ local function query_external_map(map_config, upstreams, key, callback, task)
         local params_table = {}
         for k, v in pairs(key) do
           if type(v) == 'string' then
-            table.insert(params_table, string.format('%s=%s', url_encode_string(k), url_encode_string(v)))
+            table.insert(params_table, string.format('%s=%s', lua_util.url_encode_string(k), lua_util.url_encode_string(v)))
           end
         end
         url = string.format('%s?%s', url, table.concat(params_table, '&'))
@@ -294,6 +282,11 @@ local function rspamd_map_add_from_ucl(opt, mtype, description, callback)
     end
 
     if opt[1] then
+      local function check_plain_map(line)
+        return lua_util.str_startswith(line, 'http')
+            or lua_util.str_startswith(line, 'file:')
+            or lua_util.str_startswith(line, '/')
+      end
       -- Adjust each element if needed
       local adjusted
       for i, source in ipairs(opt) do
@@ -311,6 +304,7 @@ local function rspamd_map_add_from_ucl(opt, mtype, description, callback)
       if mtype == 'radix' then
 
         if string.find(opt[1], '^%d') then
+          -- List of numeric stuff (hope it's ipnets definitions)
           local map = rspamd_config:radix_from_ucl(opt)
 
           if map then
@@ -338,7 +332,7 @@ local function rspamd_map_add_from_ucl(opt, mtype, description, callback)
           end
         end
       elseif mtype == 'regexp' or mtype == 'glob' then
-        if string.find(opt[1], '^/%a') or string.find(opt[1], '^http') then
+        if check_plain_map(opt[1]) then
           -- Plain table
           local map = rspamd_config:add_map {
             type = mtype,
@@ -372,7 +366,8 @@ local function rspamd_map_add_from_ucl(opt, mtype, description, callback)
           end
         end
       else
-        if string.find(opt[1], '^/%a') or string.find(opt[1], '^http') then
+        -- Not regexp/glob
+        if check_plain_map(opt[1]) then
           -- Plain table
           local map = rspamd_config:add_map {
             type = mtype,
@@ -553,17 +548,17 @@ exports.rspamd_maybe_check_map = rspamd_maybe_check_map
 -- @function lua_maps.fill_config_maps(mname, options, defs)
 -- Fill maps that could be defined in defs, from the config in the options
 -- Defs is a table indexed by a map's parameter name and defining it's config,
--- for example:
-defs = {
-  my_map = {
-    type = 'map',
-    description = 'my cool map',
-    optional = true,
-  }
-}
--- Then this function will look for opts.my_map parameter and try to replace it's with
--- a map with the specific type, description but not failing if it was empty.
--- It will also set options.my_map_orig to the original value defined in the map
+-- @example
+-- defs = {
+--   my_map = {
+--     type = 'map',
+--     description = 'my cool map',
+--     optional = true,
+--   }
+-- }
+-- -- Then this function will look for opts.my_map parameter and try to replace it with
+-- -- a map with the specific type, description but not failing if it was empty.
+-- -- It will also set options.my_map_orig to the original value defined in the map.
 --]]
 exports.fill_config_maps = function(mname, opts, map_defs)
   assert(type(opts) == 'table')
